# My Ersilia Python Package


This package provides some utils used by ersilia-pack.

## Tools

### IO
- read_smiles: Dispatch to the appropriate SMILES reader based on file suffix.
- write_out: Dispatch to CSV or binary writer based on file suffix.

## About the Ersilia Open Source Initiative

The [Ersilia Open Source Initiative](https://ersilia.io) is a tech-nonprofit organization fueling sustainable research in the Global South. Ersilia's main asset is the [Ersilia Model Hub](https://github.com/ersilia-os/ersilia), an open-source repository of AI/ML models for antimicrobial drug discovery.

![Ersilia Logo](assets/Ersilia_Brand.png)
